@@ -25,16 +25,7 @@ import re
 import os
 from fnmatch import fnmatch
 import hashlib
-
-
-
-try:
-    from .xlizard_languages import languages
-except ImportError as e:
-    import sys, os
-    print("Путь Python:", sys.path)
-    print("Содержимое папки:", os.listdir(os.path.dirname(__file__)))
-    raise
+from . import version 
 
 if sys.version[0] == '2':
     from future_builtins import map, filter  # pylint: disable=W0622, F0401
