@@ -4,7 +4,7 @@ import os
 import datetime
 from combined_metrics import CombinedMetrics
 from sourcemonitor_metrics import SourceMonitorMetrics, Config
-
+from sourcemonitor_metrics import FileAnalyzer, Config
 
 def html_output(result, options, *_):
     try:
@@ -62,7 +62,7 @@ def html_output(result, options, *_):
             max_complexity = 0
             for source_function in combined.functions:
                 if source_function:
-                    func_dict = _create_dict(source_function)
+                    func_dict = _create_dict(source_function, source_file.filename)  # Передаём путь к файлу
                     if not hasattr(source_function, 'token_count'):
                         func_dict['token_count'] = 0
                     func_list.append(func_dict)
@@ -304,10 +304,25 @@ def html_output(result, options, *_):
     print(output)
     return 0
 
-
-def _create_dict(obj):
-    return obj.__dict__
-
+def _get_function_code(file_path, start_line, end_line):
+    try:
+        with open(file_path, 'r', encoding='utf-8') as f:
+            lines = f.readlines()
+            return ''.join(lines[start_line-1:end_line])
+    except Exception:
+        return ""
+    
+def _create_dict(source_function, file_path):
+    func_dict = source_function.__dict__
+    # Получаем код функции
+    func_code = _get_function_code(file_path, source_function.start_line, source_function.end_line)
+    
+    if func_code:
+        # Удаляем параметр is_function, так как метод его не принимает
+        func_dict['max_depth'] = FileAnalyzer._calculate_block_depth(func_code)
+    else:
+        func_dict['max_depth'] = 0
+    return func_dict
 
 TEMPLATE = '''<!DOCTYPE HTML PUBLIC
 "-//W3C//DTD HTML 4.01 Transitional//EN"
@@ -1139,25 +1154,33 @@ TEMPLATE = '''<!DOCTYPE HTML PUBLIC
                             Tokens <div class="tooltip-icon" data-tooltip="Number of tokens in function">?</div>
                             <span class="threshold-label">Threshold: {{ thresholds['token_count'] }}</span>
                         </th>
+                        <th>
+                            Depth <div class="tooltip-icon" data-tooltip="Maximum nesting depth">?</div>
+                            <span class="threshold-label">Threshold: {{ thresholds['max_block_depth'] }}</span>
+                        </th>
                     </tr>
                 </thead>
                 <tbody>
                     {% for func in file.functions %}
-                    <tr>
-                        <td class="function-name">{{ func.name }}</td>
-                        
-                        <td class="{% if func.cyclomatic_complexity > thresholds['cyclomatic_complexity'] %}greater-value{% else %}lesser-value{% endif %}">
-                            {{ func.cyclomatic_complexity }}
-                        </td>
-                        
-                        <td class="{% if func.nloc > thresholds['nloc'] %}greater-value{% else %}lesser-value{% endif %}">
-                            {{ func.nloc }}
-                        </td>
-                        
-                        <td class="{% if func.token_count > thresholds['token_count'] %}greater-value{% else %}lesser-value{% endif %}">
-                            {{ func.token_count }}
-                        </td>
-                    </tr>
+                        <tr>
+                            <td class="function-name">{{ func.name }}</td>
+                            
+                            <td class="{% if func.cyclomatic_complexity > thresholds['cyclomatic_complexity'] %}greater-value{% else %}lesser-value{% endif %}">
+                                {{ func.cyclomatic_complexity }}
+                            </td>
+                            
+                            <td class="{% if func.nloc > thresholds['nloc'] %}greater-value{% else %}lesser-value{% endif %}">
+                                {{ func.nloc }}
+                            </td>
+                            
+                            <td class="{% if func.token_count > thresholds['token_count'] %}greater-value{% else %}lesser-value{% endif %}">
+                                {{ func.token_count }}
+                            </td>
+                            
+                            <td class="{% if func.max_depth > thresholds['max_block_depth'] %}greater-value{% else %}lesser-value{% endif %}">
+                                {{ func.max_depth }}
+                            </td>
+                        </tr>
                     {% endfor %}
                 </tbody>
             </table>
